@@ -13,7 +13,7 @@
 ##############################################################################
 """Code to initialize the application server
 
-$Id: appsetup.py 105880 2009-11-19 15:37:49Z tlotze $
+$Id: appsetup.py 107070 2009-12-25 22:50:44Z rogerineichen $
 """
 __docformat__ = 'restructuredtext'
 
@@ -243,6 +243,9 @@ def reset():
     global __config_context
     __config_context = None
 
-from zope.testing.cleanup import addCleanUp
-addCleanUp(reset)
-del addCleanUp
+try:
+    import zope.testing.cleanup
+except ImportError:
+    pass
+else:
+    zope.testing.cleanup.addCleanUp(reset)
